@@ -45,7 +45,7 @@ def KmerSignature(signature_df:pd.DataFrame,organism:str)->None:
   
   
 
-def SequenceHomogeneity(pValueList:list,posList:list,pValueAccepted:float,organism:str) -> None:
+def SequenceHomogeneity(pValueList:list,posList:list,pValueAccepted:float,organism:str,kmerSize:int=None) -> None:
         
 
 
@@ -106,6 +106,8 @@ def SequenceHomogeneity(pValueList:list,posList:list,pValueAccepted:float,organi
         ax.text(50,2,"Genome Length (pb)",color=ticksColor,ha='center')
         
         ax.text(75,0,"Percentage of Horizontal transfers: "+str(format(len(listRedRectangles)/(len(posList)-1),'.2f')),color='black')
+        if kmerSize:
+                ax.text(25,0,"Kmer size: "+str(kmerSize),color='black')
                 
         #Legend
         legend_elements=[Patch(color=blueRectangleColor,label="Corresponding Kmer Signature"),
@@ -147,7 +149,7 @@ if __name__=='__main__':
         #Test Sequence Homogeneity
         
         listpVal,listPos=pp.SequenceHomogeneity('./testGenome.fna',5,30000)
-        SequenceHomogeneity(listpVal,listPos,0.05,'Poulet')
+        SequenceHomogeneity(listpVal,listPos,0.05,'Poulet',3)
         
         
         pass
